pub struct CronJobHandle { /* private fields */ }Expand description
Handle returned by include_exclude_cron.
Allows the caller to gracefully stop the background cron thread.
The thread will exit on the next tick after stop() is called.
Implementations
Sourceimpl CronJobHandle
impl CronJobHandle